==> pyrecipe_0.1-4.tar.gz: pyrecipe-0.1/filters/mealmaster_export.py <==
import hildon
import pyrecipe_utils

mm_header = "MMMMM----- Recipe via Meal-Master (tm)\n\n"
 
mm_end = "MMMMM"
     
class MM:
    def __init__ (self, exp_recipe_list, window, widget):
        text_final = ''
        for recipe in range(len(exp_recipe_list)):
            title = exp_recipe_list[recipe][1]
            category = exp_recipe_list[recipe][2]
            preptime = exp_recipe_list[recipe][3]
            #cooktime = exp_recipe_list[recipe][4]
            servings = exp_recipe_list[recipe][5]
            ingredients = exp_recipe_list[recipe][6]
            instructions = exp_recipe_list[recipe][7]
            notes = exp_recipe_list[recipe][8]
            imagesrc = exp_recipe_list[recipe][9]

            lista_ing = []
        
            if ingredients != '':
                ##ingredient treatment:
                il_l = ingredients.split('\n')
        
                new_list = []
                for i in range(len(il_l)):
                    new = il_l[i].split('||')
                    #new[0] == amount; new[1] == unit; new[2] == ingredient
                    if new == ['']:
                        pass
                    else:                    
                        if new[0] == new[1] == '':
                            new_list.append(new[0]+ '   ' + new[1] + '   ' + new[2])              
                        elif new[0] == '':
                            new_list.append(new[0]+ '   ' + new[1] + ' ' + new[2])            
                        elif new[1] == '':
                            new_list.append(new[0]+ '   ' + new[1] + '' + new[2])
                        else:           
                            new_list.append(new[0]+ '   ' + new[1] + ' ' + new[2])

                lista_ing = ''
                for  i in range(len(new_list)):
                    if i < len(new_list)-1:
                        lista_ing += new_list[i]+'\n'              
                    else:
                        lista_ing += new_list[i]+'\n\n\n'

            else:
                lista_ing = ''        
        
            final_title = 'Title: ' + title + '\n'
            servings = 'Servings: ' + servings + '\n'
            #cooktime = 'Cooktime: ' + cooktime + '\n'
            preptime = 'Preparation Time: ' + preptime + '\n'
            category = 'Categories: ' + category + '\n\n'
        
            final_inst = instructions + '\n'
            if notes == '':
                final_notes = '\n\n'
            else:
                final_notes = 'Note: ' + notes + '\n\n\n'

        # TODO: la imagen no es exportada asi ke si mueves el archivo a otro 
        # device no se vera la imagen

        #if imagesrc == '':
        #    html_body_img = html_body.replace('<img src="file://%s" />', '')
                
        #    final_body = html_body_img % (title, lista_ing, final_inst, \
        #                         final_notes)

        #else:
        #     final_body = html_body % (title, imagesrc, lista_ing, final_inst, \
        #                         final_notes)  
                                      
        #final_header = html_header.replace('recipetitleheader', title)
        
            mm_recipe = final_title + servings + preptime + category + \
                    lista_ing + final_inst + final_notes
        
            final_mm = mm_header + mm_recipe + mm_end

            if len(exp_recipe_list) > 1:
                text_final = text_final + final_mm + '\n\n'
            else:
                text_final = final_mm
                
         
        if len(exp_recipe_list) > 1:
            namefile = pyrecipe_utils.show_save_dialog(window, 'Recipes', 'Meal Master',\
                                                  'mmf')        
        else:
            namefile = pyrecipe_utils.show_save_dialog(window, title, 'Meal Master',\
                                                  'mmf')
        
        
        if namefile is not None:
            f=open(namefile, 'w')
            f.write(text_final)
            f.close()
            hildon.hildon_banner_show_information(widget, 'qgn_note_infoprint',\
                                             'Recipes saved')
        else:
            print 'No saving recipe'

==> pyrecipe_0.3-1.tar.gz: pyrecipe-0.3/filters/mealmaster_export.py <==
import hildon
import pyrecipe_utils

def show_info_banner(widget, msg):
    hildon.hildon_banner_show_information(widget, 'qgn_note_infoprint', msg)

mm_header = "MMMMM----- Recipe via Meal-Master (tm)\n\n"

mm_end = "MMMMM"

class MM:
    def __init__ (self, exp_recipe_list, window, widget):
        text_final = ''
        for recipe in range(len(exp_recipe_list)):
            title = exp_recipe_list[recipe][1]
            category = exp_recipe_list[recipe][2]
            preptime = exp_recipe_list[recipe][3]
            #cooktime = exp_recipe_list[recipe][4]
            servings = exp_recipe_list[recipe][5]
            ingredients = exp_recipe_list[recipe][6]
            instructions = exp_recipe_list[recipe][7]
            notes = exp_recipe_list[recipe][8]
            imagesrc = exp_recipe_list[recipe][9]

            lista_ing = []

            if ingredients != '':
                ##ingredient treatment:
                il_l = ingredients.split('\n')

                new_list = []
                for i in range(len(il_l)):
                    new = il_l[i].split('||')
                    #new[0] == amount; new[1] == unit; new[2] == ingredient
                    if new == ['']:
                        pass
                    else:
                        if new[0] == new[1] == '':
                            new_list.append(new[0]+ '   ' + new[1] + '   '
                                            + new[2])
                        elif new[0] == '':
                            new_list.append(new[0]+ '   ' + new[1] + ' '
                                            + new[2])
                        elif new[1] == '':
                            new_list.append(new[0]+ '   ' + new[1] + ''
                                            + new[2])
                        else:
                            new_list.append(new[0]+ '   ' + new[1] + ' '
                                            + new[2])

                lista_ing = ''
                for  i in range(len(new_list)):
                    if i < len(new_list)-1:
                        lista_ing += new_list[i]+'\n'
                    else:
                        lista_ing += new_list[i]+'\n\n\n'

            else:
                lista_ing = ''

            final_title = 'Title: ' + title + '\n'
            servings = 'Servings: ' + servings + '\n'
            #cooktime = 'Cooktime: ' + cooktime + '\n'
            preptime = 'Preparation Time: ' + preptime + '\n'
            category = 'Categories: ' + category + '\n\n'

            final_inst = instructions + '\n'
            if notes == '':
                final_notes = '\n\n'
            else:
                final_notes = 'Note: ' + notes + '\n\n\n'

        # TODO: la imagen no es exportada asi ke si mueves el archivo a otro
        # device no se vera la imagen

        #if imagesrc == '':
        #    html_body_img = html_body.replace('<img src="file://%s" />', '')

        #    final_body = html_body_img % (title, lista_ing, final_inst,
        #                         final_notes)

        #else:
        #     final_body = html_body % (title, imagesrc, lista_ing, final_inst,
        #                         final_notes)

        #final_header = html_header.replace('recipetitleheader', title)

            mm_recipe = final_title + servings + preptime + category + \
                    lista_ing + final_inst + final_notes

            final_mm = mm_header + mm_recipe + mm_end

            if len(exp_recipe_list) > 1:
                text_final = text_final + final_mm + '\n\n'
            else:
                text_final = final_mm


        if len(exp_recipe_list) > 1:
            namefile = pyrecipe_utils.show_filechooser_dialog(window, 'save',
                        'Save recipe as ', 'Recipes', 'Meal Master', 'mmf')
        else:
            namefile = pyrecipe_utils.show_filechooser_dialog(window, 'save',
                        'Save recipe as ', title, 'Meal Master', 'mmf')


        if namefile is not None:
            f = open(namefile, 'w')
            f.write(text_final)
            f.close()
            show_info_banner(widget, 'Recipes saved')
        else:
            print 'No saving recipe'
